pw_env_setup: Don't clear PW_PROJECT_ROOT

Don't clear PW_PROJECT_ROOT in pw_deactivate.

Bug: 287
Change-Id: I9b94a7d686e38c57cab7daa157ec0f449c476429
Reviewed-on: https://pigweed-review.googlesource.com/c/pigweed/pigweed/+/23780
Pigweed-Auto-Submit: Rob Mohr <mohrr@google.com>
Commit-Queue: Auto-Submit <auto-submit@pigweed.google.com.iam.gserviceaccount.com>
Reviewed-by: Wyatt Hepler <hepler@google.com>
diff --git a/pw_env_setup/util.sh b/pw_env_setup/util.sh
index dee793f..079b8db 100644
--- a/pw_env_setup/util.sh
+++ b/pw_env_setup/util.sh
@@ -147,8 +147,10 @@
 }
 
 pw_deactivate() {
   # Assume PW_ROOT has already been set and we need to preserve its value.
   _NEW_PW_ROOT="$PW_ROOT"
+  _NEW_PW_PROJECT_ROOT="$PW_PROJECT_ROOT"
 
   # Find deactivate script and run it.
   _PW_DEACTIVATE_SH="$_PW_ACTUAL_ENVIRONMENT_ROOT/deactivate.sh"
@@ -162,9 +164,11 @@
     _pw_deactivate &> /dev/null
   fi
 
-  # Restore PW_ROOT.
+  # Restore.
   PW_ROOT="$_NEW_PW_ROOT"
   export PW_ROOT
+  PW_PROJECT_ROOT="$_NEW_PW_PROJECT_ROOT"
+  export PW_PROJECT_ROOT
 }
 
 # The next three functions use the following variables.
@@ -147,8 +147,10 @@
 
 pw_deactivate() {
-  # Assume PW_ROOT has already been set and we need to preserve its value.
+  # Assume PW_ROOT and PW_PROJECT_ROOT has already been set and we need to
+  # preserve their values.
   _NEW_PW_ROOT="$PW_ROOT"